<?php

// Plugin group weights for drupal_add_css() and drupal_add_js().
define('CSS_PLUGIN', 200);
define('JS_PLUGIN',  200);

/**
 * Get info data specific to a given plug-in. The information will be pulled
 * from the plug-in's .pinfo file.
 * 
 * @param $pinfo_key
 *  (required) The .pinfo key in the plug-in.
 * @param $default
 *  (required) Default value if none is found.
 * @param $plugin
 *  (required) The plug-in to target.
 */
function hex_plugin_info($pinfo_key, $default, $plugin) {

  $data = hex_cache('plugins', 'hex')->data;
  if (isset($data['plugins'][$plugin]->info[$pinfo_key])) {
    $plugin_info = $data['plugins'][$plugin]->info[$pinfo_key];
  }

  // Pass through defauts.
  if (!isset($plugin_info)) {
    $plugin_info = $default;
  }

  return $plugin_info;
}

/**
 * Check to see if a plug-in exists and is active.
 *
 * @see hex_plugin_list()
 *  More details on the $set parameter.
 *
 * @param $plugin
 *  The plugin key
 * @param $set
 *  Checks for a specific set. Defaults to all active plug-ins.
 */
function hex_plugin_exists($plugin, $set = 'all.active') {
  return in_array($plugin, hex_plugin_list($set));
}

/**
 * Return the path to a given plug-in.
 * 
 * If there are multiple copies of a plug-in with the same name that exists
 * across base themes and sub-themes, the returned path will point to the most
 * active, i.e., the active sub-theme or the sub-theme closest to the current
 * theme hosting the plug-in.
 * 
 * @param $plugin
 *  (required) The plug-in name.
 */
function hex_plugin_path($plugin) {
  $data = hex_cache('plugins', 'hex')->data;
  return isset($data['plugins'][$plugin]) ? $data['plugins'][$plugin]->directory : NULL;
}

/**
 * Returns a list of plug-in's.
 *
 * The set can be used to filter the output. Use "active" for enabled plug-ins,
 * "TYPE" is for the plug-in type determined by the .pinfo "plugin.type" key
 * and the "HOST" is the theme where the plug-in is hosted.
 *
 *  - all
 *  - all.active
 *  - all.TYPE
 *  - all.TYPE.active
 *
 *  - HOST
 *  - HOST.active
 *  - HOST.TYPE
 *  - HOST.TYPE.active
 *
 * @param $set
 *  Used to filter the output. Note that none of the sets will include
 *  plug-in's hosted in disabled themes.
 */
function hex_plugin_list($set = 'all.active') {
  $data = hex_cache('plugins', 'hex')->data;
  return isset($data['lists'][$set]) ? $data['lists'][$set] : array();
}

/**
 * Returns a list of all available sets.
 *
 * @see hex_plugin_lists()
 */
function hex_plugin_sets() {
  return array_keys(hex_cache('plugins', 'hex')->data['lists']);
}