<?php

/**
 * @file
 * Theme api settings for Hexagon and any of its child themes.
 */
include_once DRUPAL_ROOT . '/' . drupal_get_path('theme', 'hex') . '/template.php';
include_once DRUPAL_ROOT . '/' . drupal_get_path('theme', 'hex') . '/includes/theme_api.inc';

/**
 * Implements hook_form_system_theme_settings_alter().
 *
 * @see hex_form_theme_settings_alter()
 *
 * Used to work around a core bug.
 * @see http://drupal.org/node/1135794
 */
function hex_form_system_theme_settings_alter(&$form, &$form_state, $form_id = NULL) {

  if (isset($form_id)) {
    return;
  }
  hex_clear_caches();

  $form['#prefix']   = '<div class="theme-summary"></div>';
  $form['#attached'] = array(
    'css' => array(hex_path('theme', 'hex') . '/styles/theme-settings-form.css'),
  );

  // Set HEX_THEMEAPI context.
  hex_active_theme(HEX_THEMEAPI, TRUE);

  // Builds the UI to enable plug-ins.
  hex_form_plugin_ui_enablers($form, $form_state);

  // Invoke custom alter in a separate namespace due to the double invoke bug.
  // hook_form_system_theme_settings_alter() should only run for actively
  // running themes while hook_form_theme_settings_hex_alter() will run for
  // theme specific forms reguardless of it running or not.
  hex_alter('form_theme_settings', $form, $form_state);

  // Previous context.
  hex_active_theme(HEX_PREVIOUS);

}

/**
 * Builds plug-in checkboxes to activate plug-ins.
 */
function hex_form_plugin_ui_enablers(&$form, &$form_state) {

  // Plug-in activation and locked list.
  $activated = $locked = array();

  foreach (hex_active_themes() as $theme) {
    foreach (hex_plugin_list("$theme.extension") as $extension) {
      if (hex_themeapi_setting("$extension.enable", 0)) {
        $activated[] = $extension;
      }
    }

    // .info activations will always be enabled and locked.
    $host_enabled  = hex_theme_info(hex_active_theme() . '.plugins', array(), $theme);
    $theme_enabled = hex_theme_info('theme.plugins', array(), $theme);
    $locked = array_merge($locked, $host_enabled, $theme_enabled);

    // Merge with theme settings.
    $activated = array_merge($activated, $host_enabled, $theme_enabled);
  }

  // Add in dependencies for the activation and locked list.
  foreach ($activated as $plugin) {
    $activated = array_merge($activated, hex_plugin_info('requires', array(), $plugin));
    $locked    = array_merge($locked,    hex_plugin_info('requires', array(), $plugin));
  }
  // Dependents that are disabled also get locked.
  foreach (array_diff(hex_plugin_list('all.extension'), $activated) as $disabled) {
    $locked = array_merge($locked, hex_plugin_info('required_by', array(), $disabled));
  }

  // Build form checkboxes.
  foreach (hex_active_themes() as $theme) {
    $plugin_checkboxes = array();

    foreach (hex_plugin_list("$theme.extension") as $plugin) {
      $dependency_text = '';
      $items = array();
      foreach (hex_plugin_info('required_by', array(), $plugin) as $key) {
        if (in_array($key, hex_plugin_list("all.extension"))) {
          $name   = hex_plugin_info('name', 'Untitled', $key);
          $title  = t('Required by plug-in !name', array('!name' => $name));
          $class  = 'required-by-plugin';
          $class .= in_array($key, $activated) ? ' enabled' : ' disabled';
          $items[] = "<span title='$title' class='$class'>$name</span>";
        }
      }
      if ($items) {
        $dependency_text .= ' <em class="plugin-required-by">' . t('Required by: !names', array('!names' => implode(', ', $items))) . '</em>';
      }

      $items = array();
      foreach (hex_plugin_info('requires', array(), $plugin) as $key) {
        $name   = hex_plugin_info('name', 'Untitled', $key);
        $title  = t('Requires plug-in !name', array('!name' => $name));
        $class  = 'requires-plugin';
        $class .= in_array($key, $activated) ? ' enabled' : ' disabled';
        $items[] = "<span title='$title' class='$class'>$name</span>";
      }
      foreach (hex_plugin_info('module.dependencies', array(), $plugin) as $key) {
        $module_info = drupal_parse_info_file(hex_path('module', $key) . "/$key.info");
        $name   = $module_info['name'];
        $title  = t('Requires module !name', array('!name' => $name));
        $class  = 'requires-module';
        $class .= in_array($key, module_list()) ? ' enabled' : ' disabled';
        $items[] = "<span title='$title' class='$class'>{$module_info['name']}</span>";
      }
      if ($items) {
        $dependency_text .= ' <em class="plugin-requires">' . t('Requires: !names', array('!names' => implode(', ', $items))) . '</em>';
      }

      $plugin_checkboxes[hex_fapi_key("$plugin.enable")] = array(
        '#plugin_key'    => $plugin,
        '#type'          => 'checkbox',
        '#title'         => hex_plugin_info('name', 'Untitled', $plugin),
        '#description'   => hex_plugin_info('description', 'No Description', $plugin) . $dependency_text,
        '#default_value' => in_array($plugin, $activated),
        '#disabled'      => in_array($plugin, $locked),
      );
    }

    if (!empty($plugin_checkboxes)) {
      if (!isset($form['plugins'])) {
        $form['plugins'] = array();
      }
      $form['plugins'] += array(
        "{$theme}_plugins" => array(
          '#title' => t('!theme Plug-ins', array('!theme' => hex_theme_info('name', 'Untitled', $theme))),
          '#type'  => 'fieldset',
        ) + $plugin_checkboxes,
      );
    }
  }
}